/* SPDX-FileCopyrightText: 2015 - Sébastien Wilmet <swilmet@gnome.org>
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#pragma once

#define GSPELL_H_INSIDE

#include <gspell/gspell-checker.h>
#include <gspell/gspell-checker-dialog.h>
#include <gspell/gspell-entry.h>
#include <gspell/gspell-entry-buffer.h>
#include <gspell/gspell-language.h>
#include <gspell/gspell-language-chooser.h>
#include <gspell/gspell-language-chooser-button.h>
#include <gspell/gspell-language-chooser-dialog.h>
#include <gspell/gspell-navigator.h>
#include <gspell/gspell-navigator-text-view.h>
#include <gspell/gspell-text-buffer.h>
#include <gspell/gspell-text-view.h>

#include <gspell/gspell-enum-types.h>

#undef GSPELL_H_INSIDE
